@@ -1,9 +1,12 @@
-__version__ = "6.0.27"
+__version__ = "6.0.34"
 
 from zuper_commons.logs import ZLogger
 
 logger = ZLogger(__name__)
-logger.info(f"aido-protocols {__version__}")
+import os
+
+path = os.path.dirname(os.path.dirname(__file__))
+logger.debug(f"aido-protocols version {__version__} path {path}")
 
 from .protocols import *
 from .protocol_agent import *
