@@ -42,6 +42,7 @@ __all__ = [
     "PROTOCOL_LEARNING",
     "PROTOCOL_NORMAL",
     "Termination",
+    "ProtocolDesc",
 ]
 
 RobotName = str
@@ -194,16 +195,14 @@ class StateDump:
     state: object
 
 
-#
-# MOTION_PARKED = "parked"
-# MOTION_MOVING = "moving"
-# NPMotion = make_Literal(MOTION_PARKED, MOTION_MOVING)
-
 ProtocolDesc = NewType("ProtocolDesc", str)
+
 PROTOCOL_NORMAL = ProtocolDesc("PROTOCOL_NORMAL")
 """ only the things that are visible """
+
 PROTOCOL_FULL = ProtocolDesc("PROTOCOL_FULL")
 """ Full state observation"""
+
 PROTOCOL_LEARNING = ProtocolDesc("PROTOCOL_LEARNING")
 """ Also includes a feedback signal"""
 
@@ -219,9 +218,6 @@ class ScenarioRobotSpec:
     controllable: bool
     protocol: Optional[ProtocolDesc]
 
-    # # if not playable
-    # motion: Optional[NPMotion]
-
 
 @dataclass
 class ScenarioDuckieSpec:
@@ -234,7 +230,7 @@ class Scenario:
     # Specification of the environments
     scenario_name: str
     environment: Any
-    player_robots: List[str]
+    player_robots: List[RobotName]
     robots: Dict[str, ScenarioRobotSpec]
     duckies: Dict[str, ScenarioDuckieSpec]
 
